@@ -876,7 +876,7 @@ static gchar*
 find_man_path (gchar* name, gchar* section)
 {
     gchar* argv[] = { "man", "-w", NULL, NULL, NULL };
-    gchar *stdout = NULL;
+    gchar *ystdout = NULL;
     gint status;
     gchar **lines;
     GError *error = NULL;
@@ -893,21 +893,21 @@ find_man_path (gchar* name, gchar* section)
     if (!g_spawn_sync (NULL, argv, NULL,
                        G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
                        NULL, NULL,
-                       &stdout, NULL, &status, &error)) {
+                       &ystdout, NULL, &status, &error)) {
         g_warning ("Couldn't find path for %s(%s). Error: %s",
                    name, section, error->message);
         g_error_free (error);
     }
 
     if (status == 0) {
-        lines = g_strsplit (stdout, "\n", 2);
-        g_free (stdout);
-        stdout = g_strdup (lines[0]);
+        lines = g_strsplit (ystdout, "\n", 2);
+        g_free (ystdout);
+        ystdout = g_strdup (lines[0]);
 
         g_strfreev (lines);
-        return stdout;
+        return ystdout;
     } else {
-        g_free (stdout);
+        g_free (ystdout);
         return NULL;
     }
 }
@@ -995,66 +995,6 @@ resolve_man_uri (YelpUri *uri)
     }
 }
 
-/*
-  Return 1 if ch is a number from 0 to 9 or a letter a-f or A-F and 0
-  otherwise. This is sort of not utf8-safe, but since we are only
-  looking for 7-bit things, it doesn't matter.
- */
-static int
-is_hex (gchar ch)
-{
-    if (((48 <= ch) && (ch <= 57)) ||
-        ((65 <= ch) && (ch <= 70)) ||
-        ((97 <= ch) && (ch <= 102)))
-        return 1;
-    return 0;
-}
-
-/*
-  Return a newly allocated string, where %ab for a,b in [0, f] is
-  replaced by the character it represents.
- */
-static gchar*
-decode_url (const gchar *url)
-{
-    if (!url) return NULL;
-
-    unsigned int len = strlen (url);
-    int hex;
-    gchar *ret = g_new (gchar, len + 1);
-    const gchar *ptr = url, *end = url + len;
-    gchar *retptr = ret, *tmp;
-
-    while (ptr < end) {
-        if (*ptr == '%' && is_hex(*(ptr + 1)) && is_hex(*(ptr + 2))) {
-            *retptr = *(ptr+1);
-            *(retptr+1) = *(ptr+2);
-            *(retptr+2) = '\0';
-
-            sscanf (retptr, "%x", &hex);
-
-            if (hex < 0 || hex > 127) {
-                g_warning ("Skipping non-7-bit character.");
-                ptr++;
-                continue;
-            }
-            *retptr = (gchar)hex;
-
-            retptr++;
-            ptr += 3;
-        }
-        else {
-            tmp = g_utf8_next_char(ptr);
-            memcpy (retptr, ptr, (tmp-ptr));
-            retptr += tmp-ptr;
-            ptr = tmp;
-        }
-    }
-    *retptr = '\0';
-
-    return ret;
-}
-
 static void
 resolve_info_uri (YelpUri *uri)
 {
@@ -1216,7 +1156,7 @@ resolve_xref_uri (YelpUri *uri)
           the url again here.
          */
         gchar* tmp = priv->page_id;
-        priv->page_id = decode_url (priv->page_id);
+        priv->page_id = g_uri_unescape_string (tmp, NULL);
         g_free (tmp);
     }
 
@@ -1227,6 +1167,13 @@ resolve_xref_uri (YelpUri *uri)
                                      priv->frag_id ? "#" : "",
                                      priv->frag_id ? priv->frag_id : "",
                                      NULL);
+    else if (g_str_has_prefix (priv->docuri, "help:"))
+        priv->fulluri = g_strconcat (priv->docuri,
+                                     priv->page_id ? "/" : "",
+                                     priv->page_id ? priv->page_id : "",
+                                     priv->frag_id ? "#" : "",
+                                     priv->frag_id ? priv->frag_id : "",
+                                     NULL);
     else if (g_str_has_prefix (priv->docuri, "file:") ||
              g_str_has_prefix (priv->docuri, "info:") )
         priv->fulluri = g_strconcat (priv->docuri,
